#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 reducers
version:              3.12.3
visibility:           public
id:                   reducers-3.12.3-3OH28QLg4tC5xW9GuEBrC8
key:                  reducers-3.12.3-3OH28QLg4tC5xW9GuEBrC8
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  f1ded098d301a0b191d20036087dec46
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-8.10.5/site-local/reducers-3.12.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/reducers-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/reducers-3.12.3
hs-libraries:         HSreducers-3.12.3-3OH28QLg4tC5xW9GuEBrC8
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    fingertree-0.1.4.2-BtlaX1boPWd7OaHKwClIz0
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    semigroupoids-5.3.5-1MUCoMhFnfRKlT8x21E1a0 text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

